@@ -40,7 +40,9 @@ from .urls_patterns import URL_ADMIN_SERVER_INFO, URL_ADMIN_CLIENT_AUTHZ_RESOURC
     URL_ADMIN_USER_CLIENT_ROLES_AVAILABLE, URL_ADMIN_USERS, URL_ADMIN_CLIENT_AUTHZ_RESOURCES_ID, URL_ADMIN_CLIENT_AUTHZ_POLICIES, \
     URL_ADMIN_CLIENT_AUTHZ_POLICIES_ID, URL_ADMIN_CLIENT_AUTHZ_PERMISSIONS, URL_ADMIN_CLIENT_AUTHZ_PERMISSIONS_ID, \
     URL_ADMIN_USER_CLIENT_ROLES_COMPOSITE_ID, URL_ADMIN_GROUP_CLIENT_ROLES, USE_ADMIN_CLIENT_AUTHZ_POLICIES_EVAL, \
-    URL_ADMIN_DEFAULT_GROUPS, URL_ADMIN_GROUP_REALM_ROLES, URL_ADMIN_USER_REALM_ROLES_COMPOSITE, URL_ADMIN_USER_LOGOUT
+    URL_ADMIN_DEFAULT_GROUPS, URL_ADMIN_GROUP_REALM_ROLES, URL_ADMIN_USER_REALM_ROLES_COMPOSITE, URL_ADMIN_USER_LOGOUT, \
+    URL_ADMIN_LIST_OF_USERS_WITH_CLIENT_ROLE, URL_ADMIN_LIST_OF_USERS_WITH_ROLE, URL_ADMIN_LIST_OF_GROUPS_WITH_CLIENT_ROLE, \
+    URL_ADMIN_LIST_OF_GROUPS_WITH_ROLE
 
 def serialize(obj):
     """JSON serializer for objects not serializable by default json code"""
@@ -1177,6 +1179,56 @@ class KeycloakAdmin:
         """
         return self._get_client_roles_of(URL_ADMIN_USER_CLIENT_ROLES, user_id, client_id)
 
+    def get_users_list_with_client_role(self, client_id, role_name, query=None):
+        """
+        Get List of Users that have the specified role name.
+
+        :param client_id: id of client (not client-id)
+        :param role_name: role_name
+        :return: Keycloak server response (array UserRepresentation)
+        """
+        if not query:
+            query = {}
+        params_path = {"realm-name": self.realm_name, "id": client_id, "role-name": role_name}
+        data_raw = self.connection.raw_get(URL_ADMIN_LIST_OF_USERS_WITH_CLIENT_ROLE.format(**params_path), **query)
+        return raise_error_from_response(data_raw, KeycloakGetError)
+
+    def get_users_list_with_role(self, role_name):
+        """
+        Return List of Users that have the specified role name.
+
+        :param role_name: role_name
+        :return: Keycloak server response (array UserRepresentation)
+        """
+        params_path = {"realm-name": self.realm_name, "role-name": role_name}
+        data_raw = self.connection.raw_get(URL_ADMIN_LIST_OF_USERS_WITH_ROLE.format(**params_path))
+        return raise_error_from_response(data_raw, KeycloakGetError)
+
+    def get_groups_list_with_role(self, role_name):
+        """
+        Return List of Groups that have the specified role name.
+
+        :param role_name: role_name
+        :return: Keycloak server response (array GroupRepresentation)
+        """
+        params_path = {"realm-name": self.realm_name, "role-name": role_name}
+        data_raw = self.connection.raw_get(URL_ADMIN_LIST_OF_GROUPS_WITH_ROLE.format(**params_path))
+        return raise_error_from_response(data_raw, KeycloakGetError)
+
+    def get_groups_list_with_client_role(self, client_id, role_name, query=None):
+        """
+        Return List of Groups that have the specified role name.
+
+        :param client_id: id of client (not client-id)
+        :param role_name: role_name
+        :return: Keycloak server response (array GroupRepresentation)
+        """
+        if not query:
+            query = {}
+        params_path = {"realm-name": self.realm_name, "id": client_id, "role-name": role_name}
+        data_raw = self.connection.raw_get(URL_ADMIN_LIST_OF_GROUPS_WITH_CLIENT_ROLE.format(**params_path), **query)
+        return raise_error_from_response(data_raw, KeycloakGetError)
+
     def get_available_client_roles_of_user(self, user_id, client_id):
         """
         Get available client role-mappings for a user.
