@@ -62,6 +62,8 @@ URL_ADMIN_GROUP_MEMBERS = "admin/realms/{realm-name}/groups/{id}/members"
 URL_ADMIN_GROUP_REALM_ROLES = "admin/realms/{realm-name}/groups/{id}/role-mappings/realm"
 URL_ADMIN_GROUP_CLIENT_ROLES = "admin/realms/{realm-name}/groups/{id}/role-mappings/clients/{client-id}"
 URL_ADMIN_DEFAULT_GROUPS = "admin/realms/{realm-name}/default-groups/{id}"
+URL_ADMIN_LIST_OF_GROUPS_WITH_ROLE = "admin/realms/{realm-name}/roles/{role-name}/groups"
+URL_ADMIN_LIST_OF_GROUPS_WITH_CLIENT_ROLE = "admin/realms/{realm-name}/clients/{id}/roles/{role-name}/groups"
 
 URL_ADMIN_CLIENTS = "admin/realms/{realm-name}/clients"
 URL_ADMIN_CLIENT = "admin/realms/{realm-name}/clients/{id}"
@@ -79,6 +81,8 @@ URL_ADMIN_CLIENT_CERTS = "admin/realms/{realm-name}/clients/{id}/certificates/{a
 
 URL_ADMIN_REALM_ROLES = "admin/realms/{realm-name}/roles"
 URL_ADMIN_REALM_ROLE = "admin/realms/{realm-name}/roles/{role-name}"
+URL_ADMIN_LIST_OF_USERS_WITH_CLIENT_ROLE = "admin/realms/{realm-name}/clients/{id}/roles/{role-name}/users"
+URL_ADMIN_LIST_OF_USERS_WITH_ROLE = "admin/realms/{realm-name}/roles/{role-name}/users"
 URL_ADMIN_REALM_IMPORT = "admin/realms"
 URL_ADMIN_IDPS = "admin/realms/{realm-name}/identity-provider/instances"
 
